@@ -12,15 +12,12 @@ class Database():
         self.host = os.getenv('DB_HOST')
         self.user = os.getenv('DB_USER')
         self.password = os.getenv('DB_PASS')
-        self.mysql_config = {
+        self.connect = connect(
             'host': '170-187-194-33.ip.linodeusercontent.com',
             'user': os.getenv('DB_USER'),
             'password': os.getenv('DB_PASS'),
             'port': '3306',
             'ssl_disabled': True
-        }
-        self.connection = connect(
-            **self.mysql_config
         )
         
         # check if database exists and create it if it doesn't exist
